@@ -12,6 +12,7 @@ use crate::{context::Context, relay::socks5::Address, ServerAddr};
 
 use super::{
     sys::{create_inbound_udp_socket, create_outbound_udp_socket},
+    AcceptOpts,
     AddrFamily,
     ConnectOpts,
 };
@@ -76,9 +77,15 @@ impl UdpSocket {
         Ok(UdpSocket(socket))
     }
 
-    /// Binds to a specific address
+    /// Binds to a specific address (inbound)
+    #[inline]
     pub async fn listen(addr: &SocketAddr) -> io::Result<UdpSocket> {
-        let socket = create_inbound_udp_socket(addr).await?;
+        UdpSocket::listen_with_opts(addr, AcceptOpts::default()).await
+    }
+
+    /// Binds to a specific address (inbound)
+    pub async fn listen_with_opts(addr: &SocketAddr, opts: AcceptOpts) -> io::Result<UdpSocket> {
+        let socket = create_inbound_udp_socket(addr, opts.ipv6_only).await?;
         Ok(UdpSocket(socket))
     }
 
