@@ -1,7 +1,7 @@
 use cfg_if::cfg_if;
 
 cfg_if! {
-    if #[cfg(feature = "replay-attack-detect")] {
+    if #[cfg(feature = "security-replay-attack-detect")] {
         mod ppbloom;
         pub use self::ppbloom::*;
     } else {
